import { Component, OnInit } from '@angular/core';
import { FormBuilder, FormGroup, Validators } from '@angular/forms';
import { AlertController, NavController } from '@ionic/angular';

@Component({
  selector: 'app-feedback',
  templateUrl: './feedback.page.html',
  styleUrls: ['./feedback.page.scss'],
})
export class FeedbackPage implements OnInit {
  feedbackForm: FormGroup = new FormGroup({});

  constructor(
    private formBuilder: FormBuilder,
    private alertController: AlertController,
    private navCtrl: NavController
  ) {}

  ngOnInit() {
    this.feedbackForm = this.formBuilder.group({
      name: ['', [Validators.required]],
      email: ['', [Validators.required, Validators.email]],
      message: ['', [Validators.required]]
    });
  }

  async submitFeedback() {
    if (this.feedbackForm.valid) {
      const { name, email, message } = this.feedbackForm.value;

      // 在这里处理反馈提交的逻辑
      // 例如，发送到服务器或显示成功消息

      // 显示成功消息
      const alert = await this.alertController.create({
        header: '提交成功',
        message: '感谢您的反馈！我们会尽快处理。',
        buttons: ['确定']
      });

      await alert.present();

      // 清空表单
      this.feedbackForm.reset();

      // 返回上一个页面
      this.navCtrl.back();
    }
  }
}